Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2147)

Unified Diff: content/renderer/service_worker/worker_fetch_context_impl.h

Issue 2890723002: Set the requester context info to the requests for off-main-thread-fetch. (Closed)
Patch Set: Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/service_worker/worker_fetch_context_impl.h
diff --git a/content/renderer/service_worker/worker_fetch_context_impl.h b/content/renderer/service_worker/worker_fetch_context_impl.h
index 9e430b193ddad827099588198bae743af8e539e3..adab0393cf4ca4419b1b0e9edea36d52b84207bf 100644
--- a/content/renderer/service_worker/worker_fetch_context_impl.h
+++ b/content/renderer/service_worker/worker_fetch_context_impl.h
@@ -36,9 +36,10 @@ class WorkerFetchContextImpl : public blink::WebWorkerFetchContext,
// mojom::ServiceWorkerWorkerClient implementation:
void SetControllerServiceWorker(int64_t controller_version_id) override;
// Sets the service worker status of the parent frame.
falken 2017/05/17 08:40:26 What's the "parent frame" when this is for a share
horo 2017/05/17 10:33:52 Added comment.
void set_service_worker_provider_id(int id);
void set_is_controlled_by_service_worker(bool flag);
+ void set_is_secure_context(bool flag);
falken 2017/05/17 08:40:26 Can you document what this flag means?
horo 2017/05/17 10:33:52 Done.
private:
mojom::WorkerURLLoaderFactoryProviderPtrInfo provider_info_;
@@ -57,6 +58,7 @@ class WorkerFetchContextImpl : public blink::WebWorkerFetchContext,
int controller_version_id_ = kInvalidServiceWorkerVersionId;
bool is_data_saver_enabled_ = false;
+ bool is_secure_context_ = false;
};
} // namespace content
@@ -36,9 +36,10 @@ class WorkerFetchContextImpl : public blink::WebWorkerFetchContext,
// mojom::ServiceWorkerWorkerClient implementation:
void SetControllerServiceWorker(int64_t controller_version_id) override;
- // Sets the service worker status of the parent frame.
+ // Sets the fetch context status of the parent frame.
falken 2017/05/17 08:40:26 What's the "parent frame" when this is for a share
horo 2017/05/17 10:33:52 Added comment.

Powered by Google App Engine
This is Rietveld 408576698